@@ -46,6 +46,7 @@ public:
     guint orientation (void) const              { return m_orientation; }
     guint pageSize (void) const                 { return m_page_size; }
     gboolean rememberEveryInput (void) const    { return m_remember_every_input; }
+    sort_option_t sortOption (void) const       { return m_sort_option; }
     gboolean shiftSelectCandidate (void) const  { return m_shift_select_candidate; }
     gboolean minusEqualPage (void) const        { return m_minus_equal_page; }
     gboolean commaPeriodPage (void) const       { return m_comma_period_page; }
@@ -96,6 +97,7 @@ protected:
     gint m_orientation;
     guint m_page_size;
     gboolean m_remember_every_input;
+    sort_option_t m_sort_option;
 
     gboolean m_shift_select_candidate;
     gboolean m_minus_equal_page;
