@@ -83,7 +83,7 @@ simplest_cn_number(gint64 num)
 }
 
 static inline const std::string
-translate_to_longform(gint64 num, const char * number[10], unit_t units[])
+translate_to_longform(gint64 num, const char * number[10], unit_t units[], int units_len)
 {
     std::string result = "";
     int cur_pos = -1;
@@ -97,7 +97,7 @@ translate_to_longform(gint64 num, const char * number[10], unit_t units[])
         int pos = cur_pos;
         size_t i = 6;
         while ( pos > 0 ) {
-            for ( i = 0; i < 7; ++i) {
+            for ( i = 0; i < units_len; ++i) {
                 pos = pos % units[i].digits;
                 if ( pos == 0 )
                     break;
@@ -133,7 +133,7 @@ translate_to_longform(gint64 num, const char * number[10], unit_t units[])
 static const std::string
 simplified_number(gint64 num)
 {
-    return translate_to_longform(num, numbers[1], units_simplified);
+    return translate_to_longform(num, numbers[1], units_simplified, G_N_ELEMENTS(units_simplified));
 }
 
 static const std::string
@@ -141,7 +141,7 @@ traditional_number(gint64 num)
 {
     if ( 0 == num )
         return numbers[0][0];
-    return translate_to_longform(num, numbers[0], units_traditional);
+    return translate_to_longform(num, numbers[0], units_traditional, G_N_ELEMENTS(units_traditional));
 }
 
 
@@ -219,16 +219,16 @@ ExtEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
     switch (m_cursor) {
     case 0: //Empty input string.
         {
-            g_return_val_if_fail ( 'i' == keyval, FALSE);
-            if ( 'i' == keyval ) {
+            g_return_val_if_fail ( 'i' == keyval || 'I' == keyval, FALSE);
+            if ( 'i' == keyval || 'I' == keyval) {
                 m_text.insert (m_cursor, keyval);
                 m_cursor++;
             }
         }
         break;
-    case 1 ... 2: // Only contains 'i' in input string.
+    case 1 ... 2: // Only contains 'i' or 'I' in input string.
         {
-            g_return_val_if_fail ( 'i' == m_text[0], FALSE);
+            g_return_val_if_fail ( 'i' == m_text[0] || 'I' == m_text[0], FALSE);
             if ( isalnum (keyval) ) {
                 m_text.insert (m_cursor, keyval);
                 m_cursor++;
@@ -237,7 +237,7 @@ ExtEditor::processKeyEvent (guint keyval, guint keycode, guint modifiers)
         break;
     default: //Here is the appended argment.
         {
-            g_return_val_if_fail ( 'i' == m_text[0], FALSE);
+            g_return_val_if_fail ( 'i' == m_text[0] || 'I' == m_text[0], FALSE);
             if (isprint (keyval)) {
                 m_text.insert (m_cursor, keyval);
                 m_cursor++;
@@ -603,12 +603,12 @@ ExtEditor::updateStateFromInput (void)
         return FALSE;
     }
 
-    if ( 'i' != m_text[0] ) {
-        g_warning ("i is expected in m_text string.\n");
+    if ( 'i' != m_text[0] && 'I' != m_text[0] ) {
+        g_warning ("'i' or 'I' is expected in m_text string.\n");
         return FALSE;
     }
 
-    m_auxiliary_text = "i";
+    m_auxiliary_text = m_text[0];
 
     m_mode = LABEL_LIST_COMMANDS;
     if ( 1 == m_text.length () ) {
