@@ -25,6 +25,7 @@
 #include <ibus.h>
 #include <stdlib.h>
 #include <locale.h>
+#include <libintl.h>
 #include "PYEngine.h"
 #include "PYPointer.h"
 #include "PYBus.h"
@@ -165,6 +166,10 @@ main (gint argc, gchar **argv)
 
     setlocale (LC_ALL, "");
 
+    bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
+    bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+    textdomain(GETTEXT_PACKAGE);
+
     context = g_option_context_new ("- ibus pinyin engine component");
 
     g_option_context_add_main_entries (context, entries, "ibus-libpinyin");
