@@ -28,38 +28,39 @@
 
 namespace PY {
 
-const gchar * const CONFIG_CORRECT_PINYIN            = "CorrectPinyin";
-const gchar * const CONFIG_FUZZY_PINYIN              = "FuzzyPinyin";
-const gchar * const CONFIG_ORIENTATION               = "LookupTableOrientation";
-const gchar * const CONFIG_PAGE_SIZE                 = "LookupTablePageSize";
-const gchar * const CONFIG_REMEMBER_EVERY_INPUT      = "RememberEveryInput";
-const gchar * const CONFIG_SHIFT_SELECT_CANDIDATE    = "ShiftSelectCandidate";
-const gchar * const CONFIG_MINUS_EQUAL_PAGE          = "MinusEqualPage";
-const gchar * const CONFIG_COMMA_PERIOD_PAGE         = "CommaPeriodPage";
-const gchar * const CONFIG_AUTO_COMMIT               = "AutoCommit";
-const gchar * const CONFIG_DOUBLE_PINYIN             = "DoublePinyin";
-const gchar * const CONFIG_DOUBLE_PINYIN_SCHEMA      = "DoublePinyinSchema";
-const gchar * const CONFIG_DOUBLE_PINYIN_SHOW_RAW    = "DoublePinyinShowRaw";
-const gchar * const CONFIG_INIT_CHINESE              = "InitChinese";
-const gchar * const CONFIG_INIT_FULL                 = "InitFull";
-const gchar * const CONFIG_INIT_FULL_PUNCT           = "InitFullPunct";
-const gchar * const CONFIG_INIT_SIMP_CHINESE         = "InitSimplifiedChinese";
-const gchar * const CONFIG_SPECIAL_PHRASES           = "SpecialPhrases";
-const gchar * const CONFIG_DICTIONARIES              = "Dictionaries";
-const gchar * const CONFIG_BOPOMOFO_KEYBOARD_MAPPING = "BopomofoKeyboardMapping";
-const gchar * const CONFIG_SELECT_KEYS               = "SelectKeys";
-const gchar * const CONFIG_GUIDE_KEY                 = "GuideKey";
-const gchar * const CONFIG_AUXILIARY_SELECT_KEY_F    = "AuxiliarySelectKey_F";
-const gchar * const CONFIG_AUXILIARY_SELECT_KEY_KP   = "AuxiliarySelectKey_KP";
-const gchar * const CONFIG_ENTER_KEY                 = "EnterKey";
-const gchar * const CONFIG_IMPORT_DICTIONARY         = "ImportDictionary";
-const gchar * const CONFIG_EXPORT_DICTIONARY         = "ExportDictionary";
-const gchar * const CONFIG_CLEAR_USER_DATA           = "ClearUserData";
-/* const gchar * const CONFIG_CTRL_SWITCH               = "CtrlSwitch"; */
-const gchar * const CONFIG_MAIN_SWITCH               = "MainSwitch";
-const gchar * const CONFIG_LETTER_SWITCH             = "LetterSwitch";
-const gchar * const CONFIG_PUNCT_SWITCH              = "PunctSwitch";
-const gchar * const CONFIG_TRAD_SWITCH               = "TradSwitch";
+const gchar * const CONFIG_CORRECT_PINYIN            = "correct_pinyin";
+const gchar * const CONFIG_FUZZY_PINYIN              = "fuzzy_pinyin";
+const gchar * const CONFIG_ORIENTATION               = "lookup_table_orientation";
+const gchar * const CONFIG_PAGE_SIZE                 = "lookup_table_page_size";
+const gchar * const CONFIG_REMEMBER_EVERY_INPUT      = "remember_every_input";
+const gchar * const CONFIG_SORT_OPTION               = "sort_candidate_option";
+const gchar * const CONFIG_SHIFT_SELECT_CANDIDATE    = "shift_select_candidate";
+const gchar * const CONFIG_MINUS_EQUAL_PAGE          = "minus_equal_page";
+const gchar * const CONFIG_COMMA_PERIOD_PAGE         = "comma_period_page";
+const gchar * const CONFIG_AUTO_COMMIT               = "auto_commit";
+const gchar * const CONFIG_DOUBLE_PINYIN             = "double_pinyin";
+const gchar * const CONFIG_DOUBLE_PINYIN_SCHEMA      = "double_pinyin_schema";
+const gchar * const CONFIG_DOUBLE_PINYIN_SHOW_RAW    = "double_pinyin_show_raw";
+const gchar * const CONFIG_INIT_CHINESE              = "init_chinese";
+const gchar * const CONFIG_INIT_FULL                 = "init_full";
+const gchar * const CONFIG_INIT_FULL_PUNCT           = "init_full_punct";
+const gchar * const CONFIG_INIT_SIMP_CHINESE         = "init_simplified_chinese";
+const gchar * const CONFIG_SPECIAL_PHRASES           = "special_phrases";
+const gchar * const CONFIG_DICTIONARIES              = "dictionaries";
+const gchar * const CONFIG_BOPOMOFO_KEYBOARD_MAPPING = "bopomofo_keyboard_mapping";
+const gchar * const CONFIG_SELECT_KEYS               = "select_keys";
+const gchar * const CONFIG_GUIDE_KEY                 = "guide_key";
+const gchar * const CONFIG_AUXILIARY_SELECT_KEY_F    = "auxiliary_select_key_f";
+const gchar * const CONFIG_AUXILIARY_SELECT_KEY_KP   = "auxiliary_select_key_kp";
+const gchar * const CONFIG_ENTER_KEY                 = "enter_key";
+const gchar * const CONFIG_IMPORT_DICTIONARY         = "import_dictionary";
+const gchar * const CONFIG_EXPORT_DICTIONARY         = "export_dictionary";
+const gchar * const CONFIG_CLEAR_USER_DATA           = "clear_user_data";
+/* const gchar * const CONFIG_CTRL_SWITCH               = "ctrl_switch"; */
+const gchar * const CONFIG_MAIN_SWITCH               = "main_switch";
+const gchar * const CONFIG_LETTER_SWITCH             = "letter_switch";
+const gchar * const CONFIG_PUNCT_SWITCH              = "punct_switch";
+const gchar * const CONFIG_TRAD_SWITCH               = "trad_switch";
 
 const pinyin_option_t PINYIN_DEFAULT_OPTION =
         PINYIN_INCOMPLETE |
@@ -93,6 +94,7 @@ LibPinyinConfig::initDefaultValues (void)
     m_orientation = IBUS_ORIENTATION_HORIZONTAL;
     m_page_size = 5;
     m_remember_every_input = FALSE;
+    m_sort_option = SORT_BY_PHRASE_LENGTH_AND_FREQUENCY;
 
     m_shift_select_candidate = FALSE;
     m_minus_equal_page = TRUE;
@@ -109,6 +111,8 @@ LibPinyinConfig::initDefaultValues (void)
     m_init_simp_chinese = TRUE;
     m_special_phrases = TRUE;
 
+    m_bopomofo_keyboard_mapping = ZHUYIN_DEFAULT;
+
     m_dictionaries = "";
 
     m_main_switch = "<Shift>";
@@ -121,20 +125,28 @@ static const struct {
     const gchar * const name;
     guint option;
 } options [] = {
-    { "IncompletePinyin",       PINYIN_INCOMPLETE|ZHUYIN_INCOMPLETE},
+    { "incomplete_pinyin",       PINYIN_INCOMPLETE|ZHUYIN_INCOMPLETE},
     /* fuzzy pinyin */
-    { "FuzzyPinyin_C_CH",       PINYIN_AMB_C_CH      },
-    { "FuzzyPinyin_Z_ZH",       PINYIN_AMB_Z_ZH      },
-    { "FuzzyPinyin_S_SH",       PINYIN_AMB_S_SH      },
-    { "FuzzyPinyin_L_N",        PINYIN_AMB_L_N       },
-    { "FuzzyPinyin_F_H",        PINYIN_AMB_F_H       },
-    { "FuzzyPinyin_L_R",        PINYIN_AMB_L_R       },
-    { "FuzzyPinyin_G_K",        PINYIN_AMB_G_K       },
-    { "FuzzyPinyin_AN_ANG",     PINYIN_AMB_AN_ANG    },
-    { "FuzzyPinyin_EN_ENG",     PINYIN_AMB_EN_ENG    },
-    { "FuzzyPinyin_IN_ING",     PINYIN_AMB_IN_ING    },
+    { "fuzzy_pinyin_c_ch",       PINYIN_AMB_C_CH      },
+    { "fuzzy_pinyin_z_zh",       PINYIN_AMB_Z_ZH      },
+    { "fuzzy_pinyin_s_sh",       PINYIN_AMB_S_SH      },
+    { "fuzzy_pinyin_l_n",        PINYIN_AMB_L_N       },
+    { "fuzzy_pinyin_f_h",        PINYIN_AMB_F_H       },
+    { "fuzzy_pinyin_l_r",        PINYIN_AMB_L_R       },
+    { "fuzzy_pinyin_g_k",        PINYIN_AMB_G_K       },
+    { "fuzzy_pinyin_an_ang",     PINYIN_AMB_AN_ANG    },
+    { "fuzzy_pinyin_en_eng",     PINYIN_AMB_EN_ENG    },
+    { "fuzzy_pinyin_in_ing",     PINYIN_AMB_IN_ING    },
     /* dynamic adjust */
-    { "DynamicAdjust",          DYNAMIC_ADJUST       },
+    { "dynamic_adjust",          DYNAMIC_ADJUST       },
+};
+
+static const struct{
+    gint sort_option_index;
+    sort_option_t sort_option;
+} sort_options [] = {
+    {0, SORT_BY_PHRASE_LENGTH_AND_FREQUENCY},
+    {1, SORT_BY_PHRASE_LENGTH_AND_PINYIN_LENGTH_AND_FREQUENCY}
 };
 
 void
@@ -182,6 +194,16 @@ LibPinyinConfig::readDefaultValues (void)
     }
     m_remember_every_input = read (CONFIG_REMEMBER_EVERY_INPUT, false);
 
+    const gint index = read (CONFIG_SORT_OPTION, 0);
+    m_sort_option = SORT_BY_PHRASE_LENGTH_AND_FREQUANCY;
+
+    for (guint i = 0; i < G_N_ELEMENTS (sort_options); i++) {
+        if (index == sort_options[i].sort_option_index) {
+            /* set sort option. */
+            m_sort_option = sort_options[i].sort_option;
+        }
+    }
+
     m_dictionaries = read (CONFIG_DICTIONARIES, std::string (""));
 
     m_main_switch = read (CONFIG_MAIN_SWITCH, std::string ("<Shift>"));
@@ -233,6 +255,16 @@ LibPinyinConfig::valueChanged (const std::string &section,
         }
     } else if (CONFIG_REMEMBER_EVERY_INPUT == name) {
         m_remember_every_input = normalizeGVariant (value, false);
+    } else if (CONFIG_SORT_OPTION == name) {
+        const gint index = normalizeGVariant (value, 0);
+        m_sort_option = SORT_BY_PHRASE_LENGTH_AND_FREQUENCY;
+
+        for (guint i = 0; i < G_N_ELEMENTS (sort_options); i++) {
+            if (index == sort_options[i].sort_option_index) {
+                /* set sort option. */
+                m_sort_option = sort_options[i].sort_option;
+            }
+        }
     } else if (CONFIG_DICTIONARIES == name) {
         m_dictionaries = normalizeGVariant (value, std::string (""));
     } else if (CONFIG_MAIN_SWITCH == name) {
@@ -279,9 +311,9 @@ LibPinyinConfig::valueChangedCallback (IBusConfig  *config,
 
     self->valueChanged (section, name, value);
 
-    if (self->m_section == "engine/pinyin")
+    if (self->m_section == "engine/libpinyin")
         LibPinyinBackEnd::instance ().setPinyinOptions (self);
-    if (self->m_section == "engine/bopomofo")
+    if (self->m_section == "engine/libbopomofo")
         LibPinyinBackEnd::instance ().setChewingOptions (self);
 }
 
@@ -290,16 +322,15 @@ static const struct {
     guint option;
 } pinyin_options [] = {
     /* correct */
-    { "CorrectPinyin_GN_NG",    PINYIN_CORRECT_GN_NG    },
-    { "CorrectPinyin_GN_NG",    PINYIN_CORRECT_GN_NG    },
-    { "CorrectPinyin_MG_NG",    PINYIN_CORRECT_MG_NG    },
-    { "CorrectPinyin_IOU_IU",   PINYIN_CORRECT_IOU_IU   },
-    { "CorrectPinyin_UEI_UI",   PINYIN_CORRECT_UEI_UI   },
-    { "CorrectPinyin_UEN_UN",   PINYIN_CORRECT_UEN_UN   },
-    { "CorrectPinyin_UE_VE",    PINYIN_CORRECT_UE_VE    },
-    { "CorrectPinyin_V_U",      PINYIN_CORRECT_V_U      },
-    { "CorrectPinyin_VE_UE",    PINYIN_CORRECT_V_U      },
-    { "CorrectPinyin_ON_ONG",   PINYIN_CORRECT_ON_ONG   },
+    { "correct_pinyin_gn_ng",    PINYIN_CORRECT_GN_NG    },
+    { "correct_pinyin_mg_ng",    PINYIN_CORRECT_MG_NG    },
+    { "correct_pinyin_iou_iu",   PINYIN_CORRECT_IOU_IU   },
+    { "correct_pinyin_uei_ui",   PINYIN_CORRECT_UEI_UI   },
+    { "correct_pinyin_uen_un",   PINYIN_CORRECT_UEN_UN   },
+    { "correct_pinyin_ue_ve",    PINYIN_CORRECT_UE_VE    },
+    { "correct_pinyin_v_u",      PINYIN_CORRECT_V_U      },
+    { "correct_pinyin_ve_ue",    PINYIN_CORRECT_V_U      },
+    { "correct_pinyin_on_ong",   PINYIN_CORRECT_ON_ONG   },
 };
 
 /* Here are the double pinyin keyboard scheme mapping table. */
@@ -316,7 +347,7 @@ static const struct{
 };
 
 PinyinConfig::PinyinConfig (Bus & bus)
-    : LibPinyinConfig (bus, "pinyin")
+    : LibPinyinConfig (bus, "libpinyin")
 {
 }
 
@@ -473,7 +504,7 @@ static const struct {
 };
 
 BopomofoConfig::BopomofoConfig (Bus & bus)
-    : LibPinyinConfig (bus, "bopomofo")
+    : LibPinyinConfig (bus, "libbopomofo")
 {
 }
 
