@@ -93,59 +93,33 @@ FullPinyinEditor::updateAuxiliaryText (void)
 
     m_buffer.clear ();
 
-    guint len = 0;
-    pinyin_get_n_pinyin (m_instance, &len);
-
-    for (guint i = 0; i < len; ++i) {
-        PinyinKey *key = NULL;
-        pinyin_get_pinyin_key (m_instance, i, &key);
-
-        PinyinKeyPos *pos = NULL;
-        pinyin_get_pinyin_key_rest (m_instance, i, &pos);
-
-        guint16 cursor = 0, end = 0;
-        pinyin_get_pinyin_key_rest_positions (m_instance, pos, &cursor, &end);
-
-        gchar * str = NULL;
-        if (G_UNLIKELY (cursor == m_cursor)) { /* at word boundary. */
-            pinyin_get_pinyin_string (m_instance, key, &str);
-            m_buffer << '|' << str;
-            g_free (str);
-        } else if (G_LIKELY (cursor < m_cursor &&
-                             m_cursor < end)) { /* in word */
-            guint16 length = 0;
-            pinyin_get_pinyin_key_rest_length (m_instance, pos, &length);
-
-            /* raw text */
-            String raw = m_text.substr (cursor, length);
-            guint offset = m_cursor - cursor;
-            m_buffer << ' ' << raw.substr (0, offset)
-                     << '|' << raw.substr (offset);
-        } else { /* other words */
-            pinyin_get_pinyin_string (m_instance, key, &str);
-            m_buffer << ' ' << str;
-            g_free (str);
-        }
-    }
-
-    if (m_cursor == m_pinyin_len)
-        m_buffer << '|';
+    gchar * aux_text = NULL;
+    pinyin_get_full_pinyin_auxiliary_text (m_instance, m_cursor, &aux_text);
+    m_buffer << aux_text;
+    g_free(aux_text);
 
     /* append rest text */
     const gchar * p = m_text.c_str() + m_pinyin_len;
     m_buffer << p;
 
-    StaticText aux_text (m_buffer);
-    Editor::updateAuxiliaryText (aux_text, TRUE);
+    StaticText text (m_buffer);
+    Editor::updateAuxiliaryText (text, TRUE);
 }
 
-void
-FullPinyinEditor::update (void)
+guint
+FullPinyinEditor::getLookupCursor (void)
 {
-    guint lookup_cursor = getLookupCursor ();
-    pinyin_guess_full_pinyin_candidates (m_instance, lookup_cursor);
+    guint lookup_cursor = getPinyinCursor ();
 
-    updateLookupTable ();
-    updatePreeditText ();
-    updateAuxiliaryText ();
+    /* as pinyin_get_pinyin_offset can't handle the last "'" characters,
+       strip the string to work around it here. */
+    String stripped = m_text;
+    size_t pos = stripped.find_last_not_of ("'") + 1;
+    if (pos < stripped.length ())
+        stripped.erase (pos);
+
+    /* show candidates when pinyin cursor is at end. */
+    if (lookup_cursor == stripped.length ())
+        lookup_cursor = 0;
+    return lookup_cursor;
 }
