@@ -38,12 +38,13 @@ public:
     virtual gboolean processKeyEvent (guint keyval, guint keycode, guint modifiers);
     virtual void reset (void);
     virtual void updateAuxiliaryText (void);
-    virtual void update (void);
 
 protected:
 
     virtual void updatePinyin (void);
 
+    virtual guint getLookupCursor (void);
+
 };
 
 };
