@@ -199,7 +199,7 @@ PinyinEditor::processKeyEvent (guint keyval, guint keycode,
 }
 
 void
-PinyinEditor::commit ()
+PinyinEditor::commit (gint index)
 {
     if (G_UNLIKELY (m_text.empty ()))
         return;
@@ -208,7 +208,7 @@ PinyinEditor::commit ()
 
     /* sentence candidate */
     char *tmp = NULL;
-    pinyin_get_sentence (m_instance, &tmp);
+    pinyin_get_sentence (m_instance, index, &tmp);
     if (tmp) {
         if (m_props.modeSimp ()) {
             m_buffer << tmp;
@@ -228,9 +228,9 @@ PinyinEditor::commit ()
         m_buffer << p;
     }
 
-    pinyin_train (m_instance);
+    pinyin_train (m_instance, index);
     if (m_config.rememberEveryInput ())
-        LibPinyinBackEnd::instance ().rememberUserInput (m_instance);
+        LibPinyinBackEnd::instance ().rememberUserInput (m_instance, index);
     LibPinyinBackEnd::instance ().modified ();
     PhoneticEditor::commit ((const gchar *)m_buffer);
     reset();
@@ -246,16 +246,14 @@ PinyinEditor::updatePreeditText ()
     }
 
     m_buffer.clear ();
-    char *tmp = NULL;
-    pinyin_get_sentence (m_instance, &tmp);
-    if (tmp) {
+    char *sentence = NULL;
+    pinyin_get_sentence (m_instance, 0, &sentence);
+    if (sentence) {
         if (m_props.modeSimp ()) {
-            m_buffer<<tmp;
+            m_buffer<<sentence;
         } else {
-            SimpTradConverter::simpToTrad (tmp, m_buffer);
+            SimpTradConverter::simpToTrad (sentence, m_buffer);
         }
-        g_free (tmp);
-        tmp = NULL;
     }
 
     /* append rest text */
@@ -266,10 +264,16 @@ PinyinEditor::updatePreeditText ()
     /* underline */
     preedit_text.appendAttribute (IBUS_ATTR_TYPE_UNDERLINE, IBUS_ATTR_UNDERLINE_SINGLE, 0, -1);
 
-    guint pinyin_cursor = getPinyinCursor ();
-    Editor::updatePreeditText (preedit_text, pinyin_cursor, TRUE);
+    size_t offset = 0;
+    guint cursor = getPinyinCursor ();
+    pinyin_get_character_offset(m_instance, sentence, cursor, &offset);
+    Editor::updatePreeditText (preedit_text, offset, TRUE);
+
+    if (sentence)
+        g_free (sentence);
 }
 
+#if 0
 void
 PinyinEditor::updateAuxiliaryText ()
 {
@@ -306,6 +310,7 @@ PinyinEditor::updateAuxiliaryText ()
     StaticText aux_text (m_buffer);
     Editor::updateAuxiliaryText (aux_text, TRUE);
 }
+#endif
 
 void
 PinyinEditor::updateLookupTable ()
