@@ -187,11 +187,17 @@ PinyinEngine::processKeyEvent (guint keyval, guint keycode, guint modifiers)
                     break;
 #ifdef IBUS_BUILD_LUA_EXTENSION
                 case IBUS_i:
-                    // do not enable lua extension when use double pinyin.
+                    // for full pinyin
                     if (PinyinConfig::instance ().doublePinyin ())
                         break;
                     m_input_mode = MODE_EXTENSION;
                     break;
+                case IBUS_I:
+                    // for double pinyin
+                    if (!PinyinConfig::instance ().doublePinyin ())
+                        break;
+                    m_input_mode = MODE_EXTENSION;
+                    break;
 #endif
 #ifdef IBUS_BUILD_ENGLISH_INPUT_MODE
                 case IBUS_v:
@@ -311,7 +317,7 @@ inline void
 PinyinEngine::showSetupDialog (void)
 {
     g_spawn_command_line_async
-        (LIBEXECDIR"/ibus-setup-libpinyin pinyin", NULL);
+        (LIBEXECDIR"/ibus-setup-libpinyin libpinyin", NULL);
 }
 
 gboolean
